@@ -1,7 +1,7 @@
 package Catmandu::Importer::SRU::Parser::mabxml;
 
-# ABSTRACT: Package transforms SRU responses into Catmandu MAB2
-our $VERSION = '0.05'; # VERSION
+#ABSTRACT: Package transforms SRU responses into Catmandu MAB2
+our $VERSION = '0.06'; #VERSION
 
 use Moo;
 use MAB2::Parser::XML;
@@ -12,9 +12,7 @@ sub parse {
 
     my $xml = $record->{recordData};
     my $parser = MAB2::Parser::XML->new( $xml ); 
-    my $record_hash = $parser->next();
-
-    return $record_hash;
+    return $parser->next();
 }
 
 
@@ -30,26 +28,23 @@ Catmandu::Importer::SRU::Parser::mabxml - Package transforms SRU responses into
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
-my %attrs = (
-    base => 'http://sru.gbv.de/gvk',
-    query => '1940-5758',
-    recordSchema => 'mabxml' ,
-    parser => 'mabxml' ,
-);
+    my %attrs = (
+        base => 'http://sru.gbv.de/gvk',
+        query => '1940-5758',
+        recordSchema => 'mabxml' ,
+        parser => 'mabxml' ,
+    );
 
-my $importer = Catmandu::Importer::SRU->new(%attrs);
+    my $importer = Catmandu::Importer::SRU->new(%attrs);
 
 =head1 DESCRIPTION
 
-Each mabxml response will be transformed into an format as defined by L<Catmandu::Importer::PICA>
-
-=head1 NAME
-
-  Catmandu::Importer::SRU::Parser::mabxml - Package transforms SRU responses into Catmandu MAB2 
+Each mabxml response will be transformed into the format defined by 
+L<Catmandu::Importer::PICA>
 
 =head1 AUTHOR
 
