@@ -1,7 +1,7 @@
 package Catmandu::MAB2;
 
-# ABSTRACT: Catmandu modules for working with MAB2 data.
-our $VERSION = '0.05'; # VERSION
+#ABSTRACT: Catmandu modules for working with MAB2 data.
+our $VERSION = '0.06'; #VERSION
 
 use strict;
 use warnings;
@@ -19,25 +19,31 @@ Catmandu::MAB2 - Catmandu modules for working with MAB2 data.
 
 =head1 VERSION
 
-version 0.05
+version 0.06
+
+=head1 DESCRIPTION
+
+Catmandu::MAB2 provides methods to work with MAB2 data within the L<Catmandu>
+framework. See L<Catmandu::Introduction> and L<http://librecat.org/> for an
+introduction into Catmandu.
 
 =head1 CATMANDU MODULES
 
-Catmandu modules for parsing, fixing and writing MAB2 data.
-
 =over
 
 =item * L<Catmandu::Importer::MAB2>
 
 =item * L<Catmandu::Exporter::MAB2>
 
+=item * L<Catmandu::Importer::SRU::Parser::mabxml>
+
 =item * L<Catmandu::Fix::mab_map>
 
 =back
 
 =head1 INTERNAL MODULES
 
-Parser and writer for MAB2 data. These modules could also be used without Catmandu.
+Parser and writer for MAB2 data.
 
 =over
 
@@ -57,23 +63,6 @@ Parser and writer for MAB2 data. These modules could also be used without Catman
 
 =back
 
-=head1 SUPPORT
-
-You can find documentation for this distribution with the perldoc command.
-
-    perldoc Catmandu::Importer::MAB2
-    perldoc Catmandu::Exporter::MAB2
-    perldoc Catmandu::Fix::mab_map
-
-You can also look for information at:
-
-    Catmandu
-        https://metacpan.org/module/Catmandu::Introduction
-        https://metacpan.org/search?q=Catmandu
-
-    LibreCat
-        http://librecat.org/tutorial/index.html
-
 =head1 AUTHOR
 
 Johann Rolschewski <rolschewski@gmail.com>
